.. image:: https://img.shields.io/pypi/v/tempora.svg
   :target: https://pypi.org/project/tempora

.. image:: https://img.shields.io/pypi/pyversions/tempora.svg

.. image:: https://img.shields.io/pypi/dm/tempora.svg

.. image:: https://img.shields.io/travis/jaraco/tempora/master.svg
   :target: http://travis-ci.org/jaraco/tempora

Objects and routines pertaining to date and time (tempora).

Modules include:

 - tempora (top level package module) contains miscellaneous
   utilities and constants.
 - timing contains routines for measuring and profiling.
 - schedule contains an event scheduler.


License
=======

License is indicated in the project metadata (typically one or more
of the Trove classifiers). For more details, see `this explanation
<https://github.com/jaraco/skeleton/issues/1>`_.
